[
https://issues.apache.org/jira/browse/MAPREDUCE-4487?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel
]
Tom White updated MAPREDUCE-4487:
---------------------------------
Attachment: MAPREDUCE-4487-mr2.patch
Here's the equivalent patch for MR2. It only has the Child exponential backoff
change (applied to YarnChild) since in trunk/branch-2 ReduceTask uses an
EventFetcher which interrupts the event fetching thread without incurring a
delay.
With the patch the time to run a sleep job (with ubertasks enabled) was 9.4s
across 10 runs (sd 1.6). Without the patch it was 10.0s (sd 1.3). I ran a
t-test on the results, and the difference wasn't significant in this case.
However, I think that the change is simple and may improve responsiveness in
some cases, without any negative side effects.
> Reduce job latency by removing hardcoded sleep statements
> ---------------------------------------------------------
>
> Key: MAPREDUCE-4487
> URL: https://issues.apache.org/jira/browse/MAPREDUCE-4487
> Project: Hadoop Map/Reduce
> Issue Type: Improvement
> Components: mrv1, performance
> Affects Versions: 1.0.3
> Reporter: Tom White
> Assignee: Tom White
> Attachments: MAPREDUCE-4487-mr2.patch, MAPREDUCE-4487.patch
>
>
> There are a few places in MapReduce where there are hardcoded sleep
> statements. By replacing them with wait/notify or similar it's possible to
> reduce latency for short running jobs.
--
This message is automatically generated by JIRA.
If you think it was sent incorrectly, please contact your JIRA administrators:
https://issues.apache.org/jira/secure/ContactAdministrators!default.jspa
For more information on JIRA, see: http://www.atlassian.com/software/jira